@@ -19,17 +19,6 @@ module RubyDebianDev
     }
   end
 
-  has_support_for 'ruby2.3' do
-    {
-      version:             '2.3',
-      binary:              '/usr/bin/ruby2.3',
-      api_version:         '2.3.0',
-      shared_library:      'libruby2.3',
-      min_ruby_version:    '1:2.3~0',
-      ruby_upper_bound:    '1:2.4~',
-    }
-  end
-
   def self.min_ruby_dependency_for(shared_library)
     RUBY_INTERPRETERS.each do |int,data|
       if data[:shared_library] == shared_library
